Module map

Module map 

A map implementation.

This is to abstract the choice of map from the user so it can be changed without breaking compatibility.

Structs

IntoIter
An owning iterator over a liquid_value::map::Map’s entries.
Iter
An iterator over a liquid_value::map::Map’s entries.
IterMut
A mutable iterator over a liquid_value::map::Map’s entries.
Keys
An iterator over a liquid_value::map::Map’s keys.
Map
Type representing a Liquid object, payload of the Value::Map variant
OccupiedEntry
An occupied Entry. It is part of the Entry enum.
VacantEntry
A vacant Entry. It is part of the Entry enum.
Values
An iterator over a liquid_value::map::Map’s values.
ValuesMut
A mutable iterator over a liquid_value::map::Map’s values.

Enums

Entry
A view into a single entry in a map, which may either be vacant or occupied. This enum is constructed from the entry method on Map.