A map implementation.
This is to abstract the choice of map from the user so it can be changed without breaking compatibility.
Structs
- Into
Iter - An owning iterator over a liquid_value::map::Map’s entries.
- Iter
- An iterator over a liquid_value::map::Map’s entries.
- IterMut
- A mutable iterator over a liquid_value::map::Map’s entries.
- Keys
- An iterator over a liquid_value::map::Map’s keys.
- Map
- Type representing a Liquid object, payload of the
Value::Mapvariant - Occupied
Entry - An occupied Entry. It is part of the
Entryenum. - Vacant
Entry - A vacant Entry. It is part of the
Entryenum. - Values
- An iterator over a liquid_value::map::Map’s values.
- Values
Mut - A mutable iterator over a liquid_value::map::Map’s values.